@@ -1,6 +1,7 @@
 package main
 
 import (
+	"bytes"
 	"context"
 	"fmt"
 	"io/ioutil"
@@ -15,7 +16,9 @@ import (
 	"github.com/spf13/pflag"
 
 	"github.com/infracost/infracost/internal/apiclient"
+	"github.com/infracost/infracost/internal/clierror"
 	"github.com/infracost/infracost/internal/config"
+	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/ui"
 	"github.com/infracost/infracost/internal/update"
 	"github.com/infracost/infracost/internal/version"
@@ -53,7 +56,7 @@ func Run(modifyCtx func(*config.RunContext), args *[]string) {
 
 	defer func() {
 		if appErr != nil {
-			if v, ok := appErr.(*panicError); ok {
+			if v, ok := appErr.(*clierror.PanicError); ok {
 				handleUnexpectedErr(ctx, v)
 			} else {
 				handleCLIError(ctx, appErr)
@@ -62,8 +65,8 @@ func Run(modifyCtx func(*config.RunContext), args *[]string) {
 
 		unexpectedErr := recover()
 		if unexpectedErr != nil {
-			withStack := fmt.Errorf("%s\n%s", unexpectedErr, debug.Stack())
-			handleUnexpectedErr(ctx, withStack)
+			panicErr := clierror.NewPanicError(fmt.Errorf("%s", unexpectedErr), debug.Stack())
+			handleUnexpectedErr(ctx, panicErr)
 		}
 
 		handleUpdateMessage(updateMessageChan)
@@ -83,6 +86,15 @@ func Run(modifyCtx func(*config.RunContext), args *[]string) {
 	appErr = rootCmd.Execute()
 }
 
+type debugWriter struct {
+	f *os.File
+}
+
+func (d debugWriter) Write(p []byte) (n int, err error) {
+	p = bytes.Trim(p, " \n\t")
+	return d.f.Write(append(p, []byte(",\n")...))
+}
+
 func newRootCmd(ctx *config.RunContext) *cobra.Command {
 	rootCmd := &cobra.Command{
 		Use:     "infracost",
@@ -109,10 +121,32 @@ func newRootCmd(ctx *config.RunContext) *cobra.Command {
 			if cmd.Name() == "comment" || (cmd.Parent() != nil && cmd.Parent().Name() == "comment") {
 				ctx.SetIsInfracostComment()
 			}
+			out, _ := cmd.Flags().GetBool("debug-report")
+			if out {
+				debugFile := "infracost-debug-report.json"
+				var f *os.File
+				var err error
+
+				if _, serr := os.Stat(debugFile); serr != nil {
+					f, err = os.OpenFile(debugFile, os.O_RDWR|os.O_CREATE|os.O_TRUNC, 0755)
+				} else {
+					f, err = os.Create(debugFile)
+				}
+
+				if err != nil {
+					return fmt.Errorf("could not generate debug report file %w", err)
+				}
+				_, _ = f.WriteString("[\n")
+
+				writer := debugWriter{f: f}
+				ctx.ErrWriter = writer
+				ctx.Config.SetLogWriter(writer)
+			}
 			err := loadGlobalFlags(ctx, cmd)
 			if err != nil {
 				return err
 			}
+
 			loadCloudSettings(ctx)
 			return nil
 		},
@@ -120,10 +154,24 @@ func newRootCmd(ctx *config.RunContext) *cobra.Command {
 			// Show the help
 			return cmd.Help()
 		},
+		PersistentPostRunE: func(cmd *cobra.Command, args []string) error {
+			out, _ := cmd.Flags().GetBool("debug-report")
+			if out {
+				if f, ok := ctx.Config.LogWriter().(debugWriter); ok {
+					_, _ = f.f.WriteString("{\"msg\":\"program finished\"}\n")
+
+					_, _ = f.f.WriteString("]")
+					_ = f.f.Close()
+				}
+			}
+
+			return nil
+		},
 	}
 
 	rootCmd.PersistentFlags().Bool("no-color", false, "Turn off colored output")
 	rootCmd.PersistentFlags().String("log-level", "", "Log level (trace, debug, info, warn, error, fatal)")
+	rootCmd.PersistentFlags().Bool("debug-report", false, "Generate a debug report file which can be sent to Infracost team")
 
 	rootCmd.AddCommand(authCmd(ctx))
 	rootCmd.AddCommand(registerCmd(ctx))
@@ -179,7 +227,7 @@ func startUpdateCheck(ctx *config.RunContext, c chan *update.Info) {
 	go func() {
 		updateInfo, err := update.CheckForUpdate(ctx)
 		if err != nil {
-			log.Debugf("error checking for update: %v", err)
+			logging.Logger.WithError(err).Debug("error checking for Infracost CLI update")
 		}
 		c <- updateInfo
 		close(c)
@@ -194,13 +242,13 @@ func loadCloudSettings(ctx *config.RunContext) {
 	dashboardClient := apiclient.NewDashboardAPIClient(ctx)
 	result, err := dashboardClient.QueryCLISettings()
 	if err != nil {
-		log.WithError(err).Debug("Failed to load settings from Infracost Cloud ")
+		logging.Logger.WithError(err).Debug("Failed to load settings from Infracost Cloud ")
 		// ignore the error so the command can continue without failing
 		return
 	}
-	log.WithFields(log.Fields{"result": fmt.Sprintf("%+v", result)}).Debug("Successfully loaded settings from Infracost Cloud")
+	logging.Logger.WithFields(log.Fields{"result": fmt.Sprintf("%+v", result)}).Debug("Successfully loaded settings from Infracost Cloud")
 
-	ctx.Config.EnableCloudForComment = result.CloudEnabled
+	ctx.Config.EnableCloudForOrganization = result.CloudEnabled
 }
 
 func checkAPIKey(apiKey string, apiEndpoint string, defaultEndpoint string) error {
@@ -221,7 +269,7 @@ func handleCLIError(ctx *config.RunContext, cliErr error) {
 
 	err := apiclient.ReportCLIError(ctx, cliErr, true)
 	if err != nil {
-		log.Warnf("Error reporting CLI error: %s", err)
+		logging.Logger.WithError(err).Warn("error reporting CLI error")
 	}
 }
 
@@ -230,7 +278,7 @@ func handleUnexpectedErr(ctx *config.RunContext, err error) {
 
 	err = apiclient.ReportCLIError(ctx, err, false)
 	if err != nil {
-		log.Warnf("Error reporting unexpected error: %s", err)
+		logging.Logger.WithError(err).Warn("error sending unexpected runtime error")
 	}
 }
 
@@ -259,7 +307,15 @@ func loadGlobalFlags(ctx *config.RunContext, cmd *cobra.Command) error {
 
 	if cmd.Flags().Changed("log-level") {
 		ctx.Config.LogLevel, _ = cmd.Flags().GetString("log-level")
-		err := ctx.Config.ConfigureLogger()
+		err := logging.ConfigureBaseLogger(ctx.Config)
+		if err != nil {
+			return err
+		}
+	}
+
+	if cmd.Flags().Changed("debug-report") {
+		ctx.Config.DebugReport, _ = cmd.Flags().GetBool("debug-report")
+		err := logging.ConfigureBaseLogger(ctx.Config)
 		if err != nil {
 			return err
 		}
@@ -295,7 +351,7 @@ func saveOutFileWithMsg(ctx *config.RunContext, cmd *cobra.Command, outFile, suc
 	}
 
 	if ctx.Config.IsLogging() {
-		log.Info(successMsg)
+		logging.Logger.Info(successMsg)
 	} else {
 		cmd.PrintErrf("%s\n", successMsg)
 	}
