@@ -93,13 +93,13 @@ func (p *DirProvider) checks() error {
 		msg := fmt.Sprintf("Terraform binary '%s' could not be found. You have two options:\n", binary)
 		msg += "1. Set a custom Terraform binary using the environment variable INFRACOST_TERRAFORM_BINARY.\n\n"
 		msg += fmt.Sprintf("2. Set --path to a Terraform plan JSON file. See %s for how to generate this.", ui.LinkString("https://infracost.io/troubleshoot"))
-		return clierror.NewSanitizedError(errors.Errorf(msg), "Terraform binary could not be found")
+		return clierror.NewCLIError(errors.Errorf(msg), "Terraform binary could not be found")
 	}
 
 	out, err := exec.Command(binary, "-version").Output()
 	if err != nil {
 		msg := fmt.Sprintf("Could not get version of Terraform binary '%s'", binary)
-		return clierror.NewSanitizedError(errors.Errorf(msg), "Could not get version of Terraform binary")
+		return clierror.NewCLIError(errors.Errorf(msg), "Could not get version of Terraform binary")
 	}
 
 	fullVersion := strings.SplitN(string(out), "\n", 2)[0]
@@ -359,7 +359,7 @@ func (p *DirProvider) runPlan(opts *CmdOptions, spinner *ui.Spinner, initOnFail
 			cmdName = "terragrunt run-all plan"
 		}
 		msg := fmt.Sprintf("%s failed", cmdName)
-		return "", planJSON, clierror.NewSanitizedError(fmt.Errorf("%s: %s", msg, err), msg)
+		return "", planJSON, clierror.NewCLIError(fmt.Errorf("%s: %s", msg, err), msg)
 	}
 
 	spinner.Success()
@@ -376,7 +376,7 @@ func (p *DirProvider) runInit(opts *CmdOptions, spinner *ui.Spinner) error {
 	flags, err := shellquote.Split(p.InitFlags)
 	if err != nil {
 		msg := "parsing terraform-init-flags failed"
-		return clierror.NewSanitizedError(fmt.Errorf("%s: %s", msg, err), msg)
+		return clierror.NewCLIError(fmt.Errorf("%s: %s", msg, err), msg)
 	}
 
 	args = append(args, "init", "-input=false", "-no-color")
@@ -396,7 +396,7 @@ func (p *DirProvider) runInit(opts *CmdOptions, spinner *ui.Spinner) error {
 			cmdName = "terragrunt run-all init"
 		}
 		msg := fmt.Sprintf("%s failed", cmdName)
-		return clierror.NewSanitizedError(fmt.Errorf("%s: %s", msg, err), msg)
+		return clierror.NewCLIError(fmt.Errorf("%s: %s", msg, err), msg)
 	}
 
 	spinner.Success()
@@ -471,7 +471,7 @@ func (p *DirProvider) runShow(opts *CmdOptions, spinner *ui.Spinner, planFile st
 			cmdName = "terragrunt show"
 		}
 		msg := fmt.Sprintf("%s failed", cmdName)
-		return []byte{}, clierror.NewSanitizedError(fmt.Errorf("%s: %s", msg, err), msg)
+		return []byte{}, clierror.NewCLIError(fmt.Errorf("%s: %s", msg, err), msg)
 	}
 	spinner.Success()
 
