@@ -1,22 +1,18 @@
 package google
 
 import (
+	"github.com/infracost/infracost/internal/resources/google"
 	"github.com/infracost/infracost/internal/schema"
 )
 
-func GetComputeVPNGatewayRegistryItem() *schema.RegistryItem {
+func getComputeVPNGatewayRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:  "google_compute_vpn_gateway",
 		RFunc: NewComputeVPNGateway,
 	}
 }
-
 func NewComputeVPNGateway(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
-	region := d.Get("region").String()
-	return &schema.Resource{
-		Name: d.Address,
-		SubResources: []*schema.Resource{
-			networkEgress(region, u, "Network egress", "IPSec traffic", ComputeVPNGateway),
-		},
-	}
+	r := &google.ComputeVPNGateway{Address: d.Address, Region: d.Get("region").String()}
+	r.PopulateUsage(u)
+	return r.BuildResource()
 }
